@@ -24,13 +24,13 @@ def _send_activities_chunk():
         'Content-Type': 'application/json'
     }
     full_url = CONFIG.server_host + px_constants.API_ACTIVITIES
-    chunk = ACTIVITIES_BUFFER[:10]
+    chunk = ACTIVITIES_BUFFER[:CONFIG.max_buffer_len]
     for _ in range(len(chunk)):
         ACTIVITIES_BUFFER.pop(0)
     px_httpc.send(full_url=full_url, body=json.dumps(chunk), headers=default_headers, config=CONFIG, method='POST')
 
 def send_activities_in_thread():
-    if len(ACTIVITIES_BUFFER) >= 10:
+    if len(ACTIVITIES_BUFFER) >= CONFIG.max_buffer_len:
         CONFIG.logger.debug('Posting {} Activities'.format(len(ACTIVITIES_BUFFER)))
         t1 = threading.Thread(target=_send_activities_chunk)
         t1.daemon = True
